@@ -8,7 +8,7 @@ use Illuminate\Support\Facades\Log;
 
 use App\Classes\LDAP\Attribute;
 use App\Exceptions\InvalidUsage;
-use App\Interfaces\MD5Updates;
+use App\Interfaces\MD5Update;
 use App\Ldap\Entry;
 
 /**
@@ -122,7 +122,7 @@ final class AttributeType extends Base
 	 * @param Collection $ocs
 	 * @return Collection
 	 */
-	private function heirachy(Collection $ocs): Collection
+	private function hierarchy(Collection $ocs): Collection
 	{
 		$result = collect();
 
@@ -326,7 +326,7 @@ final class AttributeType extends Base
 	public function validation(array $array): ?array
 	{
 		// For each item in array, we need to get the OC hierarchy
-		$heirachy = $this->heirachy(collect($array)
+		$hierarchy = $this->hierarchy(collect($array)
 			->flatten()
 			->filter());
 
@@ -340,7 +340,7 @@ final class AttributeType extends Base
 				: Entry::TAG_NOTAG);
 
 		// Add in schema required by conditions
-		if (($heirachy->intersect($this->required_by_object_classes->keys())->count() > 0)
+		if (($hierarchy->intersect($this->required_by_object_classes->keys())->count() > 0)
 			&& (! collect($validation->get($this->name_lc))->contains('required'))) {
 			$validation
 				->prepend(array_merge(['required','min:1'],$validation->get($nolangtag,[])),$nolangtag)
@@ -353,7 +353,7 @@ final class AttributeType extends Base
 						attribute: $this->name,
 						values: [Entry::TAG_NOTAG=>['']])
 					)->no_attr_tags
-						? 'max:'.($x->hasHelper() ? 2 : 1)+(($x instanceof MD5Updates) ? 1 : 0)
+						? 'max:'.($x->hasHelper() ? 2 : 1)+(($x instanceof MD5Update) ? 1 : 0)
 						: NULL)
 				],
 					$validation->get($this->name_lc,[])),$this->name_lc);
