@@ -6,6 +6,7 @@ use Carbon\Carbon;
 use Exception;
 use Illuminate\Support\Arr;
 use Illuminate\Support\Collection;
+use Illuminate\Support\Facades\Auth;
 use Illuminate\Support\Facades\Cache;
 use Illuminate\Support\Facades\Config;
 use Illuminate\Support\Facades\Log;
@@ -176,7 +177,7 @@ final class Server
 			}
 		}
 
-		Log::debug(sprintf('%s:- Got namingcontexts',self::LOGKEY),['namingcontexts'=>$namingcontexts]);
+		Log::debug(sprintf('%s:- Got namingcontexts',self::LOGKEY),['namingcontexts'=>$namingcontexts->join(':')]);
 
 		if (! $objects)
 			return $namingcontexts;
@@ -187,8 +188,14 @@ final class Server
 			// @note: Incase our rootDSE didnt return a namingcontext, we'll have no base DNs
 			foreach ($namingcontexts as $dn) {
 				$o = self::get($dn)->read()->find($dn);
-				$o->setBase();
-				$result->push($o);
+
+				if ($o) {
+					$o->setBase();
+					$result->push($o);
+
+				} else {
+					Log::alert(sprintf('%s:! DN [%s] was not found for [%s]',self::LOGKEY,$dn,Auth::user()?->getDn ?: __('Anonymous')));
+				}
 			}
 
 			return $result->filter()->sort(fn($item)=>$item->sort_key);
@@ -266,7 +273,7 @@ final class Server
 				->read()
 				->firstOrFail();
 
-			Log::debug(sprintf('%s:Fetched rootDSE ',self::LOGKEY),['rootDSE'=>$rootdse]);
+			Log::debug(sprintf('%s:Fetched rootDSE',self::LOGKEY),['rootDSE'=>$rootdse]);
 		}
 
 		return $rootdse;
@@ -287,6 +294,7 @@ final class Server
 			->get(
 				dn: $dn,
 				attrs: array_merge($attrs,[
+					'numsubordinates',	// Needed for the tree to know if an entry has children
 					'hassubordinates',	// Needed for the tree to know if an entry has children
 					'c'					// Needed for the tree to show icons for countries
 				]))
@@ -327,6 +335,22 @@ final class Server
 		return $result;
 	}
 
+	/**
+	 * Get the baseDN for a given DN
+	 *
+	 * @param string $dn
+	 * @return Entry
+	 */
+	public function get_base(string $dn): Entry
+	{
+		foreach (self::baseDNs() as $base) {
+			if (\Str::endsWith($dn,$base->getDn()))
+				break;
+		}
+
+		return $base;
+	}
+
 	/**
 	 * Get an attribute key for an attributetype name
 	 *
@@ -338,13 +362,8 @@ final class Server
 	{
 		static $attributes = $this->schema('attributetypes');
 
-		$attrid = $attributes->search(fn($item)=>$item->names->contains($key));
-
-		// Second chance search using lowercase items (our Entry attribute keys are lowercase)
-		if ($attrid === FALSE)
-			$attrid = $attributes->search(fn($item)=>$item->names_lc->contains(strtolower($key)));
-
-		return $attrid;
+		return $attributes
+			->search(fn($item)=>$item->names_lc->contains(strtolower($key)));
 	}
 
 	/**
@@ -403,12 +422,12 @@ final class Server
 				$schema_dn = $this->schemaDN();
 				Log::debug(sprintf('%s:/ Found out SchemaDN is [%s]',self::LOGKEY,$schema_dn));
 
-				// @note: 389DS does not return subschemaSubentry unless it is requested
 				// @note: If the LDAP server doesnt return a subschemasubentry, then we end up looping
 				try {
 					Log::debug(sprintf('%s:/ Fetching schema at [%s]',self::LOGKEY,$schema_dn));
 
-					$schema = $this->fetch($schema_dn,['*','+','subschemaSubentry']);
+					// @note OpenBSD/ldapd doesnt return the schema with +, it needs to call schema attributes explicitly
+					$schema = $this->fetch($schema_dn,[$item]);
 
 				} catch (InvalidUsage $e) {
 					abort(599,$e->getMessage());
@@ -424,10 +443,8 @@ final class Server
 				switch ($item) {
 					case 'attributetypes':
 						Log::debug(sprintf('%s:Attribute Types',self::LOGKEY));
-						// build the array of attribueTypes
-						//$syntaxes = $this->SchemaSyntaxes($dn);
 
-						foreach ($schema->{$item} as $line) {
+						foreach ($schema->{$item} ?: [] as $line) {
 							if (is_null($line) || ! strlen($line))
 								continue;
 
@@ -460,7 +477,7 @@ final class Server
 					case 'ldapsyntaxes':
 						Log::debug(sprintf('%s:LDAP Syntaxes',self::LOGKEY));
 
-						foreach ($schema->{$item} as $line) {
+						foreach ($schema->{$item} ?: [] as $line) {
 							if (is_null($line) || ! strlen($line))
 								continue;
 
@@ -473,7 +490,7 @@ final class Server
 					case 'matchingrules':
 						Log::debug(sprintf('%s:Matching Rules',self::LOGKEY));
 
-						foreach ($schema->{$item} as $line) {
+						foreach ($schema->{$item} ?: [] as $line) {
 							if (is_null($line) || ! strlen($line))
 								continue;
 
@@ -493,7 +510,7 @@ final class Server
 					case 'objectclasses':
 						Log::debug(sprintf('%s:Object Classes',self::LOGKEY));
 
-						foreach ($schema->{$item} as $line) {
+						foreach ($schema->{$item} ?: [] as $line) {
 							if (is_null($line) || ! strlen($line))
 								continue;
 
@@ -568,16 +585,17 @@ final class Server
 	 */
 	public function schemaDN(): string
 	{
-		return Arr::get($this->rootDSE->subschemasubentry,0);
+		return $this->rootDSE
+			->getFirstAttribute('subschemaSubentry','');
 	}
 
-	public function subordinates(string $dn,array $attrs=['dn']): ?LDAPCollection
+	public function subordinates(string $dn,array $attrs=['dn'],bool $containers=TRUE): ?LDAPCollection
 	{
 		return $this
 			->get(
 				dn: $dn,
 				attrs: array_merge($attrs,[]))
-			->rawFilter('(hassubordinates=TRUE)')
+			->rawFilter(sprintf('(hassubordinates=%s)',$containers ? 'TRUE' : 'FALSE'))
 			->search()
 			->get() ?: NULL;
 	}
