@@ -3,11 +3,9 @@
 namespace App\Http\Controllers;
 
 use Illuminate\Http\Request;
-use Illuminate\Support\Arr;
 use Illuminate\Support\Collection;
 use Illuminate\Support\Facades\Auth;
 use Illuminate\Support\Facades\File;
-use Illuminate\View\View;
 
 use App\Exceptions\InvalidUsage;
 use App\Ldap\Entry;
@@ -22,7 +20,7 @@ class HomeController extends Controller
 	 *
 	 * @param Request $request
 	 * @param Collection|null $old
-	 * @return View
+	 * @return \Illuminate\View\View
 	 * @throws InvalidUsage
 	 * @throws \Psr\Container\ContainerExceptionInterface
 	 * @throws \Psr\Container\NotFoundExceptionInterface
@@ -81,7 +79,7 @@ class HomeController extends Controller
 				->with('dn',$key['dn'])
 				->with('o',$o)
 				->with('page_actions',collect([
-					'create'=>($x=($o->getObjects()->except('entryuuid')->count() > 0)),
+					'create'=>($x=($o->getObjects()->except($o->getGuidKey())->count() > 0)),
 					'copy'=>$x,
 					'delete'=>! $o->has_children,
 					'edit'=>$x,
@@ -137,7 +135,7 @@ class HomeController extends Controller
 		$content = NULL;
 
 		if (Auth::check()) {
-			$image = Arr::get(Auth::user()->getAttribute('jpegphoto'),0);
+			$image = Auth::user()->getFirstAttribute('jpegphoto');
 			$content = 'image/jpeg';
 		}
 
