@@ -1,9 +1,11 @@
 <div class="input-group has-validation">
 	<input type="text"
-		   {{ $attributes->class(['is-invalid'=>($e=$errors->get($o->name_lc.'.'.$dotkey))]) }}
-		   name="{{ $o->name_lc }}[{{ $attrtag }}][]"
-		   value="{{ $value }}"
-		   readonly>
+		{{ $attributes->only('class')->class([
+			'is-invalid'=>($e=$errors->get($o->name_lc.'.'.$dotkey))
+		]) }}
+		name="{{ $o->name_lc }}[{{ $attrtag }}][]"
+		value="{{ $value }}"
+		readonly>
 
 	@if($value)
 		@if($o->dn_exists($value))
