@@ -1,9 +1,10 @@
 @use(App\Classes\LDAP\Attribute\Binary\{Certificate,CertificateList,JpegPhoto})
 @use(App\Classes\LDAP\Attribute\{Member,ObjectClass})
+@use(App\Ldap\Entry)
 
 <span class="p-0 m-0">
 	@if($o->is_rdn && $editable)
-		<span id="entry-rename" class="btn btn-sm btn-outline-focus mt-3" data-bs-toggle="modal" data-bs-target="#page-modal"><i class="fas fa-fw fa-exchange"></i> @lang('Rename')</span>
+		<button type="button" class="btn btn-sm btn-outline-focus mt-3" name="entry-rename" data-bs-toggle="modal" data-bs-target="#page-modal"><i class="fas fa-fw fa-exchange"></i> @lang('Rename')</button>
 
 	@elseif(($edit || $editable) && $o->can_addvalues && (! $o->isDynamic()))
 		@switch(get_class($o))
@@ -12,7 +13,7 @@
 				@break
 
 			@case(Member::class)
-				<button type="button" name="member-manage" @class(['btn','btn-sm','btn-outline-primary','mt-3','addable','d-none'=>$editable]) data-attr={{ $o->name_lc }} data-bs-toggle="modal" data-bs-target="#page-modal"><i class="fas fa-fw fa-plus"></i> @lang('Add Member')</button>
+				<button type="button" name="member-manage" @class(['btn','btn-sm','btn-outline-primary','mt-3','addable','d-none'=>$editable]) data-attr="{{ $o->name_lc }}" data-bs-toggle="modal" data-bs-target="#page-modal"><i class="fas fa-fw fa-plus"></i> @lang('Add Member')</button>
 
 				@section('page-scripts')
 					<script type="text/javascript">
@@ -27,6 +28,7 @@
 
 								var that = $(this).find('.modal-content');
 								modal_attr = $(item.relatedTarget).data('attr');
+								modal_tag = '{{ Entry::TAG_NOTAG }}';
 
 								$.ajax({
 									method: 'GET',
@@ -88,7 +90,7 @@
 					<script type="text/javascript">
 						<!-- attribte.widget.options/objectclass -->
 						// Sort select lists
-						const sort_text = function(a,b) {
+						var sort_text = function(a,b) {
 							let at = $(a).text(),
 								bt = $(b).text();
 							return (at > bt) ? 1 : ((at < bt) ? -1 : 0);
@@ -101,6 +103,12 @@
 								.toArray();
 						}
 
+						function newattr_options() {
+							return $('select#newattr option')
+								.map((key,item)=>item.value)
+								.toArray();
+						}
+
 						$(document).ready(function() {
 							var modal_rendered = false;
 							var oc_added = [];		// Object classes being added to this entry
@@ -175,9 +183,11 @@
 													}).fail(ajax_error);
 
 													// If this is a new entry, add the required attributes to the RDN
-													if (! rdn_options().includes(item)) {
-														$('select#rdn').append(new Option(item,item));
-														rdn_options_sort = true;
+													if ($('select#rdn').length) {
+														if (! rdn_options().includes(item)) {
+															$('select#rdn').append(new Option(item,item));
+															rdn_options_sort = true;
+														}
 													}
 
 													// Remove the new attributes from the newattr select list.
@@ -329,14 +339,15 @@
 								// Create a new entry when Add Value clicked
 								$('form#dn-edit #{{ $o->name_lc }}-addnew.addable').on('click',function() {
 									var attribute = $(this).closest('attribute');
-									var active = attribute.find('.tab-content .tab-pane.active');
+									var active = attribute.find('.tab-content .tab-pane.active div.input-group:last');
 
-									active.find('input:last')
+									active
 										.clone()
-										.attr('value','')
+										.insertAfter(active)
+										.find('input:last')
+										.val('')
 										.attr('placeholder','[@lang('NEW')]')
 										.addClass('border-focus')
-										.appendTo(active);
 								});
 							});
 						</script>
