@@ -24,7 +24,7 @@
 						<td>BaseDN(s)</td>
 						<td>
 							<table class="table table-sm table-borderless">
-								@foreach($server->baseDNs(TRUE)->sort(fn($item)=>$item->sort_key) as $item)
+								@foreach($server->baseDNs() as $item)
 									<tr>
 										<td class="ps-0">{{ $item->getDn() }}</td>
 									</tr>
@@ -44,6 +44,18 @@
 						<td>Root URL</td>
 						<td>{{ request()->root() }}</td>
 					</tr>
+
+					<!-- Locale -->
+					<tr>
+						<td>Locale</td>
+						<td>{{ __('locale') }} [{{ config('app.locale') }}]</td>
+					</tr>
+
+					<!-- PHP Version -->
+					<tr>
+						<td>PHP Version</td>
+						<td>{{ phpversion() }}/{{ app()->version() }}</td>
+					</tr>
 					</tbody>
 				</table>
 			</div>
