@@ -24,12 +24,6 @@
 @section('page-scripts')
 	<script type="text/javascript">
 		<!-- fragment.dn.add_attr -->
-		function newattr_options() {
-			return $('select#newattr option')
-				.map((key,item)=>item.value)
-				.toArray();
-		}
-
 		// Add an attribute to a page
 		function attr_render(item) {
 			$.ajax({
@@ -47,11 +41,13 @@
 			}).fail(ajax_error);
 
 			// Add the attr to the RDN
-			if (! rdn_options().includes(item.target.value)) {
-				$('select#rdn').append(new Option(item.target.value,item.target.value));
+			if ($('select#rdn').length) {
+				if (! rdn_options().includes(item.target.value)) {
+					$('select#rdn').append(new Option(item.target.value,item.target.value));
 
-				rdn_options_sort = true;
-				sort_rdn_options();
+					rdn_options_sort = true;
+					sort_rdn_options();
+				}
 			}
 
 			// Remove the option from the new attr list
@@ -67,7 +63,7 @@
 				attr_render(item);
 			});
 
-			@if($o->getMissingAttributes()->count())
+			@if($edit && $o->getMissingAttributes()->count())
 				$('#newattr-select.d-none')
 					.removeClass('d-none')
 					.find('select')
