@@ -106,7 +106,7 @@
 														<x-attribute :o="$ao" :edit="false" :editable="true" :new="true" :template="null" :updated="$updated->contains($ao->name_lc)"/>
 													@endforeach
 
-													@include('fragment.dn.add_attr')
+													@include('fragment.dn.add_attr',['edit'=>FALSE])
 												</div>
 											</div>
 										</form>
@@ -149,7 +149,7 @@
 			// Switch focus to the default templte
 			$('span[href="#template-default"]').click();
 
-			$('#dn-edit input[name="dn"]').val(dn);
+			$('form#dn-edit input[name="dn"]').val(dn);
 
 			$('form#dn-edit').attr('readonly',false);
 			$('button[id=entry-edit]')
@@ -159,34 +159,37 @@
 				.attr('disabled',true);
 
 			// Find all input items and turn off readonly
-			$('input.form-control').not('.modal_edit, .no-edit').each(function() {
+			$('form#dn-edit input.form-control').not('.modal-edit, .no-edit').each(function() {
 				$(this).attr('readonly',false);
 			});
 
 			// Find all input items and turn off readonly
-			$('textarea.form-control').not('.no-edit').each(function() {
+			$('form#dn-edit textarea.form-control').not('.no-edit').each(function() {
 				$(this).attr('readonly',false);
 			});
 
 			// Any select areas that are disabled
-			$('attribute .form-select').not('.no-edit').each(function() {
+			$('form#dn-edit attribute .form-select').not('.no-edit').each(function() {
 				$(this).prop('disabled',false);
 			});
 
 			// Any attribute select areas
-			$('#newattr.form-select').each(function() {
+			$('form#dn-edit #newattr.form-select').each(function() {
 				$(this).prop('disabled',false);
 			});
 
 			// Objectclasses that can be removed
-			$('.input-group-end i.d-none').removeClass('d-none');
+			$('form#dn-edit .input-group-end i.d-none').removeClass('d-none');
 
-			$('.row.d-none').removeClass('d-none');
-			$('button.addable.d-none').removeClass('d-none');
-			$('button.deletable.d-none').removeClass('d-none');
+			$('form#dn-edit + div.row.d-none').removeClass('d-none');
+			$('form#dn-edit button.addable.d-none').removeClass('d-none');
+			$('form#dn-edit button.deletable.d-none').removeClass('d-none');
+
+			// Any readonly-checkbox
+			$('form#dn-edit .readonly-checkbox').removeClass('readonly-checkbox');
 
 			@if($o->getMissingAttributes()->count())
-				$('#newattr-select.d-none').removeClass('d-none');
+				$('form#dn-edit #newattr-select.d-none').removeClass('d-none');
 			@endif
 		}
 
@@ -303,6 +306,25 @@
 
 						break;
 
+					case 'values-show':
+						modal_attr = $(item.relatedTarget).data('attr');
+						modal_tag = $(item.relatedTarget).data('tag');
+						console.log('model_attr:',modal_attr);
+
+						$.ajax({
+							method: 'GET',
+							url: '{{ url('modal/values-show') }}/'+dn,
+							dataType: 'html',
+							cache: false,
+							beforeSend: before_send_spinner(that)
+
+						}).done(function(html) {
+							that.empty().append(html);
+
+						}).fail(ajax_error);
+
+						break;
+
 					default:
 						console.log('No action for button:'+$(item.relatedTarget).attr('name'));
 				}
